@@ -65,8 +65,12 @@ export class RangeListForm {
     }
 
     get value() {
-        const formValue = this.fields.map(field => {return field.value}).filter(
-            value => {return value !== false}
+        const formValue = this.fields.map(field => {
+            return field.value
+        }).filter(
+            value => {
+                return value !== false
+            }
         )
         if (formValue.length === 0) {
             return false
