@@ -40,59 +40,6 @@ export const contactsTemplate = ({contacts}) =>
         </tr>`
     ).join('')
 
-const rightsPulldown = () =>
-    `<div class="fw-pulldown fw-right">
-    <ul>
-        <li>
-            <span class="fw-pulldown-header" title="${gettext("Basic access rights")}">
-                ${gettext("Basic")}
-            </span>
-        </li>
-        <li>
-            <span class="fw-pulldown-item" data-rights="write" title="${gettext("Write")}">
-                <i class="icon-access-write" ></i>&nbsp;${gettext("Write")}
-            </span>
-        </li>
-        <li>
-            <span class="fw-pulldown-item" data-rights="write-tracked" title="${gettext("Write with changes tracked")}">
-                <i class="icon-access-write-tracked" ></i>&nbsp;${gettext("Write tracked")}
-            </span>
-        </li>
-        <li>
-            <span class="fw-pulldown-item" data-rights="comment" title="${gettext("Comment")}">
-                <i class="icon-access-comment"></i>&nbsp;${gettext("Comment")}
-            </span>
-        </li>
-        <li>
-            <span class="fw-pulldown-item" data-rights="read" title="${gettext("Read")}">
-                <i class="icon-access-read"></i>&nbsp;${gettext("Read")}
-            </span>
-        </li>
-        <li>
-            <span class="fw-pulldown-header" title="${
-    gettext("Access rights used within document review")
-}">
-                ${gettext("Review")}
-            </span>
-        </li>
-        <li>
-            <span class="fw-pulldown-item" data-rights="read-without-comments" title="${
-    gettext("Read document but not see comments and chats of others")
-}">
-                <i class="icon-access-read-without-comments"></i>&nbsp;${gettext("No comments")}
-            </span>
-        </li>
-        <li>
-            <span class="fw-pulldown-item" data-rights="review" title="${
-    gettext("Comment, but not see comments and chats of others")
-}">
-                <i class="icon-access-review"></i>&nbsp;${gettext("Review")}
-            </span>
-        </li>
-    </ul>
-</div>`
-
-
 /** The template for the right hand side list of users (the collaborators of the current document) of the access rights dialogue. */
 export const collaboratorsTemplate = ({collaborators}) =>
     collaborators.map(collaborator =>
@@ -106,7 +53,6 @@ export const collaboratorsTemplate = ({collaborators}) =>
             <div class="fw-inline edit-right-wrapper">
                 <i class="icon-access-right icon-access-${collaborator.rights}"></i>
                 <i class="fa fa-caret-down edit-right"></i>
-                ${rightsPulldown()}
             </div>
         </td>
         <td width="50" align="center">
@@ -130,7 +76,6 @@ export const invitesTemplate = ({invites}) =>
                 <div class="fw-inline edit-right-wrapper">
                     <i class="icon-access-right icon-access-${invite.rights}"></i>
                     <i class="fa fa-caret-down edit-right"></i>
-                    ${rightsPulldown()}
                 </div>
             </td>
             <td width="50" align="center">
