@@ -233,7 +233,11 @@ export class ModCommentStore {
             if (!this.comments[id].answers) {
                 this.comments[id].answers = []
             }
-            this.comments[id].answers.push(answer)
+            const answerFound = this.comments[id].answers.find(Answer => Answer.id ===
+                answer.id)
+            if (!answerFound) {
+                this.comments[id].answers.push(answer)
+            }
         }
 
         if (local || (!this.mod.interactions.isCurrentlyEditing())) {
@@ -253,7 +257,7 @@ export class ModCommentStore {
     }
 
     deleteLocalAnswer(id, answerId, local) {
-        if (this.comments[id] && this.comments[id].answers) {
+        if (this.comments[id]?.answers) {
             this.comments[id].answers = this.comments[id].answers.filter(
                 answer => answer.id !== answerId)
         }
@@ -273,7 +277,7 @@ export class ModCommentStore {
     }
 
     updateLocalAnswer(id, answerId, answerText, local) {
-        if (this.comments[id] && this.comments[id].answers) {
+        if (this.comments[id]?.answers) {
             const answer = this.comments[id].answers.find(answer => answer.id ===
                 answerId)
             if (answer) {
@@ -306,7 +310,7 @@ export class ModCommentStore {
                 })
             } else if (event.type == "update") {
                 const found = this.comments[event.id]
-                if (found && found.id) {
+                if (found?.id) {
                     result.push(Object.assign({type: 'update'}, found))
                 } else {
                     result.push({
@@ -315,7 +319,7 @@ export class ModCommentStore {
                 }
             } else if (event.type == "create") {
                 const found = this.comments[event.id]
-                if (found && found.id) {
+                if (found?.id) {
                     result.push(Object.assign({type: 'create'}, found))
                 } else {
                     result.push({
@@ -325,7 +329,7 @@ export class ModCommentStore {
             } else if (event.type == "add_answer") {
                 const found = this.comments[event.id]
                 let foundAnswer
-                if (found && found.id && found.answers) {
+                if (found?.id && found?.answers) {
                     foundAnswer = found.answers.find(answer => answer.id === event.answerId)
                 }
                 if (foundAnswer) {
@@ -339,7 +343,7 @@ export class ModCommentStore {
                 }
             } else if (event.type == "delete_answer") {
                 const found = this.comments[event.id]
-                if (found && found.id && found.answers) {
+                if (found?.id && found?.answers) {
                     result.push({
                         type: "delete_answer",
                         id: event.id,
@@ -353,7 +357,7 @@ export class ModCommentStore {
             } else if (event.type == "update_answer") {
                 const found = this.comments[event.id]
                 let foundAnswer
-                if (found && found.id && found.answers) {
+                if (found?.id && found?.answers) {
                     foundAnswer = found.answers.find(answer => answer.id ===
                         event.answerId)
                 }
