@@ -4,5 +4,6 @@ export {FigureDialog} from "./figure"
 export {MathDialog} from "./math"
 export {LanguageDialog} from "./language"
 export {LinkDialog} from "./link"
-export {TableDialog, TableResizeDialog} from "./table"
+export {TableDialog, TableConfigurationDialog} from "./table"
 export {RevisionDialog} from "./revision"
+export {OrderedListStartDialog} from "./ordered_list"
