@@ -2,9 +2,9 @@ import {imageEditTemplate} from "./templates"
 import {setCheckableLabel, addAlert, Dialog, ContentMenu} from "../../common"
 import {imageEditModel} from './model'
 export class ImageEditDialog {
-    constructor(imageDB, imageId = false, editor) {
+    constructor(imageDB, imageId = false, page) {
         this.imageDB = imageDB
-        this.editor = editor
+        this.page = page
         this.imageId = imageId
         this.dialog = false
         this.copyright = this.imageId ?
@@ -15,13 +15,16 @@ export class ImageEditDialog {
                 freeToRead: true,
                 licenses: []
             }
+        this.menu = this.page.menu?.imageEditModel || imageEditModel()
     }
 
     //open a dialog for uploading an image
     init() {
-
+        if (this.page.app.isOffline()) {
+            this.showOffline()
+            return Promise.resolve()
+        }
         const returnPromise = new Promise(resolve => {
-
             this.dialog = new Dialog({
                 title: this.imageId ? gettext('Update Image Information') : gettext('Upload Image'),
                 id: 'editimage',
@@ -60,7 +63,7 @@ export class ImageEditDialog {
             event.stopImmediatePropagation()
 
             const contentMenu = new ContentMenu({
-                menu: imageEditModel(),
+                menu: this.menu,
                 width: 220,
                 page: this,
                 menuPos: {X: event.pageX - 50, Y: event.pageY + 50},
@@ -79,11 +82,11 @@ export class ImageEditDialog {
         this.rotation = 0
         this.cropped = false
 
-        selectButton.addEventListener('click', () =>{
+        selectButton.addEventListener('click', () => {
             mediaInputSelector.click()
         })
 
-        mediaInputSelector.addEventListener('change', () =>{
+        mediaInputSelector.addEventListener('change', () => {
             this.mediaInput = mediaInputSelector.files[0]
             const fr = new window.FileReader()
             fr.onload = () => {
@@ -151,6 +154,10 @@ export class ImageEditDialog {
                     resolve(imageId)
                 },
                 errors => {
+                    if (this.page.app.isOffline()) {
+                        this.showOffline()
+                        return
+                    }
                     this.displayCreateImageError(errors)
                     addAlert('error', gettext('Some errors were found. Please examine the form.'))
                 }
@@ -158,4 +165,8 @@ export class ImageEditDialog {
         })
     }
 
+    showOffline() {
+        addAlert('info', gettext('You are currently offline. Please try again after going online.'))
+    }
+
 }
